package com.yizhi.message.application.controller.remote;


import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.yizhi.core.application.event.EventWrapper;
import com.yizhi.message.application.constans.Constans;
import com.yizhi.message.application.domain.MessageAccount;
import com.yizhi.message.application.event.MessageEventHandler;
import com.yizhi.message.application.service.MessageAccountService;
import com.yizhi.message.application.service.MessageRemindService;
import com.yizhi.message.application.vo.MessageRemindVo;
import com.yizhi.message.application.vo.MessageTaskRemindVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 前端控制器 用户消息记录表
 * </p>
 *
 * @author hutao123
 * @since 2019-09-09
 */
@RestController
@Api(tags = "用户消息接口，后端内部调用接口，不给前端用")
@RequestMapping("/remote/manage/messageAccount")
public class RemoteMessageAccountComtroller {
    private static final Logger LOGGER = LoggerFactory.getLogger(RemoteMessageAccountComtroller.class);
    @Autowired
    private MessageAccountService messageAccountService;
    @Autowired
    private MessageRemindService messageRemindService;

    /**
     * 用于触发事件，直接发送消息
     *
     * @return
     */
    @GetMapping("/batchSave")
    @ApiOperation(value = "用于触发事件，直接发送消息", response = Integer.class)
    public Boolean save(@RequestBody List<MessageAccount> messageAccounts) {

        if (!CollectionUtils.isEmpty(messageAccounts)) {
            return messageAccountService.insertBatch(messageAccounts);
        }
        return false;
    }

    @PostMapping("/processBizEvent")
    public void processBizEvent(@RequestBody com.yizhi.core.application.vo.MessageRemindVo data) {
        MessageRemindVo mrv = new MessageRemindVo();
        BeanUtils.copyProperties(data,mrv);
        LOGGER.info("收到消息，开始保存待发消息，其remindVo："+ mrv);
        if (mrv != null) {
            if(CollectionUtils.isEmpty(data.getMessageTaskRemindVos())){
                data.getMessageTaskRemindVos().stream().forEach(mtv->{
                    MessageTaskRemindVo m = new MessageTaskRemindVo();
                    BeanUtils.copyProperties(mtv,m);
                    mrv.getMessageTaskRemindVos().add(m);
                   }
                );

            }
            messageRemindService.insertMessageRemind(mrv);
        }else {
            LOGGER.info("remindVo"+mrv+"接到的消息内容为空！！！");
        }
    }


    @GetMapping("/getList")
    @ApiOperation(value = "获取列表", response = Integer.class)
    public List<MessageAccount> getList(@RequestParam("taskType") Integer taskType, @RequestParam("taskId") Long taskId) {
        EntityWrapper wrapper = new EntityWrapper();
        wrapper.eq("deleted", Constans.NOT_DELETED);
        wrapper.eq("relation_id", taskId);
        wrapper.eq("relation_type", taskType);
        wrapper.setSqlSelect("account_id");
        return messageAccountService.selectList(wrapper);
    }
    @GetMapping("/getOne")
    @ApiOperation(value = "获取单条消息", response = Integer.class)
    public MessageAccount getOne(@RequestParam("accountId") Long accountId, @RequestParam("taskType") Integer taskType, @RequestParam("taskId") Long taskId) {
        EntityWrapper wrapper = new EntityWrapper();
        wrapper.eq("deleted", Constans.NOT_DELETED);
        wrapper.eq("relation_id", taskId);
        wrapper.eq("relation_type", taskType);
        wrapper.eq("account_id",accountId);
        wrapper.setSqlSelect("account_id");
        return messageAccountService.selectOne(wrapper);
    }

}

